import json
from pathlib import Path


class BasePromptsFromJsonMixin:
    @staticmethod
    def _load_json_file(path: str):
        with Path(path).open() as json_file:
            return json.load(json_file)

    @property
    def base_prompts(self):
        try:
            base_prompts_files = getattr(self, "base_prompts_files")
            base_prompts = []
            for prompt_file in base_prompts_files:
                base_prompts += self._load_json_file(prompt_file)
            return base_prompts
        except AttributeError:
            try:
                base_prompts_file = getattr(self, "base_prompts_file")
                return self._load_json_file(base_prompts_file)
            except AttributeError:
                raise Exception(
                    f'Class {self.__class__} does not exhibit attribute "base_prompts_files" or "base_prompts_file" which is needed for `BasePromptsFromJsonMixin`.'
                )


class BasePromptsFromGeneration:
    pass
